Summary:       Library for producing small, fast columnar storage for Hadoop workloads
Name:          liborc
Version:       1.8.1
Release:       8%{?dist}
License:       Apache-2.0
URL:           http://orc.apache.org/
Source0:       https://archive.apache.org/dist/orc/orc-%{version}/orc-%{version}.tar.gz

Patch3000:     0001-cmake.patch

BuildRequires: cmake gcc-c++
BuildRequires: gnupg2 protobuf-devel zlib-devel libzstd-devel lz4-devel snappy-devel

ExcludeArch:   i686 armv7hl

%description
ORC is a self-describing type-aware columnar file format designed
for Hadoop workloads. It is optimized for large streaming reads,
but with integrated support for finding required rows quickly.
Storing data in a columnar format lets the reader read, decompress,
and process only the values that are required for the current query.
Because ORC files are type-aware, the writer chooses the most
appropriate encoding for the type and builds an internal index as
the file is written. Predicate pushdown uses those indexes to
determine which stripes in a file need to be read for a particular
query and the row indexes can narrow the search to a particular set
of 10,000 rows. ORC supports the complete set of types in Hive,
including the complex types: structs, lists, maps, and unions.

%package -n liborc1
Summary: Library for producing small, fast columnar storage for Hadoop workloads
Provides: %{name} = %{version}-%{release}

%description -n liborc1
ORC is a self-describing type-aware columnar file format designed
for Hadoop workloads. It is optimized for large streaming reads,
but with integrated support for finding required rows quickly.
Storing data in a columnar format lets the reader read, decompress,
and process only the values that are required for the current query.
Because ORC files are type-aware, the writer chooses the most
appropriate encoding for the type and builds an internal index as
the file is written. Predicate pushdown uses those indexes to
determine which stripes in a file need to be read for a particular
query and the row indexes can narrow the search to a particular set
of 10,000 rows. ORC supports the complete set of types in Hive,
including the complex types: structs, lists, maps, and unions.

%package devel
Summary:  Header files, libraries and development documentation for %{name}
Requires: %{name}1 = %{version}-%{release}

%description devel
ORC is a self-describing type-aware columnar file format designed
for Hadoop workloads. It is optimized for large streaming reads,
but with integrated support for finding required rows quickly.
Storing data in a columnar format lets the reader read, decompress,
and process only the values that are required for the current query.
Because ORC files are type-aware, the writer chooses the most
appropriate encoding for the type and builds an internal index as
the file is written. Predicate pushdown uses those indexes to
determine which stripes in a file need to be read for a particular
query and the row indexes can narrow the search to a particular set
of 10,000 rows. ORC supports the complete set of types in Hive,
including the complex types: structs, lists, maps, and unions.
Contains header files for developing applications that use the %{name}
library.

%prep
%autosetup -n orc-%{version} -p1

%build
export CXXFLAGS="$RPM_OPT_FLAGS -Wno-error=stringop-overflow"

%cmake \
    -DCMAKE_CXX_STANDARD=17 \
    -DOVERRIDE_INSTALL_PREFIX=/usr \
    -DCMAKE_COLOR_MAKEFILE:BOOL=OFF \
    -DCMAKE_INSTALL_LIBDIR:PATH=%{_libdir} \
    -DINSTALL_LIBDIR:PATH=%{_libdir} \
    -DBUILD_SHARED_LIBS:BOOL=on \
    -DBUILD_LIBHDFSPP:BOOL=off \
    -DSNAPPY_HOME="/usr" \
    -DLZ4_HOME="/usr" \
    -DZLIB_HOME="/usr" \
    -DZSTD_HOME="/usr" \
    -DGTEST_HOME="/usr" \
    -DPROTOBUF_HOME="/usr" \
    -Dorc_VERSION="%{version}" \
    -DBUILD_CPP_TESTS=off \
    -DBUILD_TOOLS=off \
    -DBUILD_JAVA=off \
    -DANALYZE_JAVA=off \
    "-GUnix Makefiles"
%cmake_build

%install
%cmake_install
mkdir %{buildroot}%{_docdir}/%{name}1
mv %{buildroot}%{_docdir}/orc/NOTICE %{buildroot}%{_docdir}/%{name}1/
mkdir -p %{buildroot}/%{_defaultlicensedir}/%{name}1
mv %{buildroot}%{_docdir}/orc/LICENSE %{buildroot}/%{_defaultlicensedir}/%{name}1/

%files -n %{name}1
%license LICENSE
%doc README.md NOTICE
%{_libdir}/liborc.so.*

%files devel
%dir %{_includedir}/orc
%{_includedir}/orc/*.hh
%dir %{_includedir}/orc/sargs
%{_includedir}/orc/sargs/*.hh
%{_libdir}/liborc.so
%dir %{_libdir}/cmake/orc
%{_libdir}/cmake/orc/orc*.cmake

%changelog
* Mon Sep 18 2023 Miaojun Dong <zoedong@tencent.com> - 1.8.1-8
- Rebuild for protobuf-24.2

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.8.1-7
- Rebuilt for OpenCloudOS Stream 23.09

* Thu Sep 07 2023 jackeyji <jackeyji@tencent.com> - 1.8.1-6
- Rebuilt for protobuf 3.21.12

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.8.1-5
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.8.1-4
- Rebuilt for OpenCloudOS Stream 23

* Wed Dec 21 2022 Miaojun Dong <zoedong@tencent.com> - 1.8.1-3
- rebuild for protobuf-3.19

* Tue Dec 20 2022 Miaojun Dong <zoedong@tencent.com> - 1.8.1-2
- rebuild for protobuf-3.19

* Sun Dec 18 2022 Miaojun Dong <zoedong@tencent.com> - 1.8.1-1
- initial build
